@@ -16,7 +16,7 @@ def rocketmq_handler_wrapper(f):
 
 
 class ComsumerRocketMQ(ComsumerFactory):
-    def __init__(self, comsumer_group_id='', lookup_address='', node_address='', access_key='', access_secret='', thread_num=None, batch_size=None):
+    def __init__(self, comsumer_group_id='', lookup_address='', node_address='', access_key='', access_secret='', thread_num=None, batch_size=None, **mq_options):
         self.consumer = PushConsumer(comsumer_group_id)
         self.consumer.set_name_server_address(lookup_address)
         if thread_num and thread_num > 0:
@@ -31,8 +31,8 @@ class ComsumerRocketMQ(ComsumerFactory):
         self.consumer.subscribe(
             topic_group, rocketmq_handler_wrapper(callback), expression=topic)
 
-    def start(self):
+    def Start(self):
         self.consumer.start()
 
-    def stop(self):
+    def Stop(self):
         self.consumer.shutdown()
